python-outbrain |build-status|
===============

Python wrapper for Outbrain Amplify API


Copy over yaml file for outbrain credentials

  cp outbrain.yml.example outbrain.yml

Edit usename and password (note that this is the outbrain username and not the user email).

.. |build-status| image:: https://travis-ci.org/bpmason1/python-outbrain.svg?branch=master
   :target: https://travis-ci.org/bpmason1/python-outbrain
   :alt: Build status
